import _  from 'lodash';
import moduleTools  from './module-tools.js';
import osTools  from './os-tools.js';

/**
 * Returns an array of locales supported by the local cldr data.
 * @param {string}cldrDir cldr dictionary
 * @return {Array}
 */
let getSupportedLanguages = (cldrDir)=> {
  //let cldrDir = path.join(__dirname, '..', 'cldr');
  let languages = [];
  moduleTools.enumerateFilesSync(cldrDir, null, ['json'], false, function (content) {
    let cldr = null;
    try {
      cldr = JSON.parse(content);
    } catch (e) {
      throw new Error('CLDR read error on ' + osTools.getPlatform());
    }

    let mainLanguages = Object.keys(cldr.main || {});
    languages = _.concat(languages, mainLanguages);
  });

  return _.uniq(languages);
};

/**
 * if language be supported by cldr return true
 * @param {string} language Supported languages in CLDR notation
 * @param {string}cldrDirectory cldr directory
 * @return {boolean} true for 'en' and supported languages in CLDR notation.
 */
const isSupportedLanguage = (language,  cldrDirectory)=> {
  if (!language)
    return false;
  let supportLanguages = getSupportedLanguages(cldrDirectory);
  return (supportLanguages.indexOf(language) >= 0);
};

/**
 * if language be supported by cldr return true
 * @param {string} language Supported languages in CLDR notation
 * @param {string}cldrDirectory cldr directory
 * @return {boolean} true for 'en' and supported languages in CLDR notation.
 */
const getSupportedLanguage = (language,  cldrDirectory)=> (
  isSupportedLanguage(language, cldrDirectory) ? language : null
);

const cldrTools = {
  getSupportedLanguages,
  getSupportedLanguage,
  isSupportedLanguage,
};

export default cldrTools;
